@@ -151,17 +151,17 @@ class ResourceEndpointProxy(GenericEndpointProxy):
         self.url = service.location + '/data/' + resource
         self.descriptor = descriptor
 
-    def read(self, owner, ref, retry_when_empty_result=None):
+    def read(self, owner, ref, retry_when_empty_result=None, backoff_strategy=None):
         self._add_correlation_id()
         return self.http.get(self.url + '/' + ref, self._create_owner_param(owner), resource_name=self.resource,
-                             retry_when_empty_result=retry_when_empty_result)
+                             retry_when_empty_result=retry_when_empty_result, backoff_strategy=backoff_strategy)
 
     def store(self, owner, json_object):
         self._add_correlation_id()
         return self.http.post(self.url + '/', json_object, self._create_owner_param(owner), resource_name=self.resource)
 
     def browse(self, owner, criteria=None, fields=None, query_string=None, prefetch_pages=1,
-               retry_when_empty_result=None):
+               retry_when_empty_result=None, backoff_strategy=None):
 
         self._add_correlation_id()
         params = criteria.get_criteria_params() if criteria else {}
@@ -170,7 +170,7 @@ class ResourceEndpointProxy(GenericEndpointProxy):
 
         return PageBrowser(endpoint=self, resource_name=self.resource, criteria=criteria,
                            query_string=query_string, params=params, prefetch_pages=prefetch_pages,
-                           retry_when_empty_result=retry_when_empty_result)
+                           retry_when_empty_result=retry_when_empty_result, backoff_strategy=backoff_strategy)
 
     def _create_fields_params(self, fields):
         if fields:
@@ -309,14 +309,18 @@ class PageBrowser(object):
     and then will do lazy pagination load of rest of pages till finding a page with no next link.
     """
 
+    # TODO retry_when_empty_result deprecated, it should be a key of the backoff_strategy dictionary. When removed
+    #  get rid of the pylint disable-too-many-arguments
+    # pylint: disable-msg=too-many-arguments
     def __init__(self, endpoint=None, resource_name=None, criteria=None, query_string=None, params=None,
-                 prefetch_pages=1, retry_when_empty_result=None):
+                 prefetch_pages=1, retry_when_empty_result=None, backoff_strategy=None):
         self._response_cache = []
         self._resource_name = resource_name
         self._endpoint = endpoint
         self.params = params
         self._criteria = criteria
         self._retry_when_empty_result = retry_when_empty_result
+        self._backoff_strategy = backoff_strategy
         self.response_builder = ResponseBuilder(descriptor=endpoint.descriptor, criteria=self._criteria)
         self.query_string = query_string
         self.url = self._build_url()
@@ -340,7 +344,8 @@ class PageBrowser(object):
         params = self._get_params_for_request()
         self._remove_owner_if_needed(self.params, url)
         response = self._endpoint.http.get(url, params=params, resource_name=self._resource_name,
-                                           retry_when_empty_result=self._retry_when_empty_result)
+                                           retry_when_empty_result=self._retry_when_empty_result,
+                                           backoff_strategy=self._backoff_strategy)
         response_wrapper = self._get_response(self._endpoint, response)
 
         return self._get_next_url(response), response_wrapper
